@@ -1,6 +1,57 @@
 package Module::Faker;
+BEGIN {
+  $Module::Faker::VERSION = '0.007';
+}
 use 5.008;
-use Moose;
+use Moose 0.33;
+# ABSTRACT: build fake dists for testing CPAN tools
+
+use Module::Faker::Dist;
+
+use File::Next ();
+
+
+has source => (is => 'ro', required => 1);
+has dest   => (is => 'ro', required => 1);
+
+has dist_class => (
+  is  => 'ro',
+  isa => 'Str',
+  required => 1,
+  default  => sub { 'Module::Faker::Dist' },
+);
+
+sub BUILD {
+  my ($self) = @_;
+
+  for (qw(source dest)) {
+    my $dir = $self->$_;
+    Carp::croak "$_ directory does not exist"     unless -e $dir;
+    Carp::croak "$_ directory is not a directory" unless -d $dir;
+    Carp::croak "$_ directory is not readable"    unless -r $dir;
+  }
+
+  Carp::croak "$_ directory is not writeable" unless -w $self->dest;
+}
+
+sub make_fakes {
+  my ($class, $arg) = @_;
+
+  my $self = ref $class ? $class : $class->new($arg);
+
+  my $iter = File::Next::files($self->source);
+
+  while (my $file = $iter->()) {
+    my $dist = $self->dist_class->from_file($file);
+    $dist->make_archive({ dir => $self->dest });
+  }
+}
+
+no Moose;
+1;
+
+__END__
+=pod
 
 =head1 NAME
 
@@ -8,15 +59,7 @@ Module::Faker - build fake dists for testing CPAN tools
 
 =head1 VERSION
 
-version 0.006
-
-=cut
-
-our $VERSION = '0.006';
-
-use Module::Faker::Dist;
-
-use File::Next ();
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -55,52 +98,16 @@ methods of the same name.  Valid arguments are:
 
   dist_class - the class used to fake dists; default: Module::Faker::Dist
 
-=cut
+=head1 AUTHOR
 
-has source => (is => 'ro', required => 1);
-has dest   => (is => 'ro', required => 1);
+Ricardo Signes <rjbs@cpan.org>
 
-has dist_class => (
-  is  => 'ro',
-  isa => 'Str',
-  required => 1,
-  default  => sub { 'Module::Faker::Dist' },
-);
+=head1 COPYRIGHT AND LICENSE
 
-sub BUILD {
-  my ($self) = @_;
+This software is copyright (c) 2008 by Ricardo Signes.
 
-  for (qw(source dest)) {
-    my $dir = $self->$_;
-    Carp::croak "$_ directory does not exist"     unless -e $dir;
-    Carp::croak "$_ directory is not a directory" unless -d $dir;
-    Carp::croak "$_ directory is not readable"    unless -r $dir;
-  }
-
-  Carp::croak "$_ directory is not writeable" unless -w $self->dest;
-}
-
-sub make_fakes {
-  my ($class, $arg) = @_;
-
-  my $self = ref $class ? $class : $class->new($arg);
-
-  my $iter = File::Next::files($self->source);
-
-  while (my $file = $iter->()) {
-    my $dist = $self->dist_class->from_file($file);
-    $dist->make_archive({ dir => $self->dest });
-  }
-}
-
-=head1 COPYRIGHT AND AUTHOR
-
-This distribution was written by Ricardo Signes, E<lt>rjbs@cpan.orgE<gt>.
-
-Copyright 2008.  This is free software, released under the same terms as perl
-itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-no Moose;
-1;
