@@ -1,8 +1,9 @@
 use strict;
 use warnings;
 package Module::Faker::Heavy;
-
-our $VERSION = '0.006';
+BEGIN {
+  $Module::Faker::Heavy::VERSION = '0.007';
+}
 
 use Carp ();
 use Text::Template;
@@ -47,6 +48,32 @@ sub _render {
 
 1;
 
+
+
+=pod
+
+=head1 NAME
+
+Module::Faker::Heavy
+
+=head1 VERSION
+
+version 0.007
+
+=head1 AUTHOR
+
+Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
 __DATA__
 __META.yml__
 ---
