@@ -1,8 +1,9 @@
 package Module::Faker::Module;
+BEGIN {
+  $Module::Faker::Module::VERSION = '0.007';
+}
 use Moose;
 
-our $VERSION = '0.006';
-
 use Module::Faker::Package;
 
 has filename => (
@@ -39,3 +40,28 @@ sub as_string {
 
 no Moose;
 1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Module::Faker::Module
+
+=head1 VERSION
+
+version 0.007
+
+=head1 AUTHOR
+
+Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2008 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
